.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install fulfil_client

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv fulfil_client
    $ pip install fulfil_client
